View Source mix combo_new (combo_new v0.12.0)
Generates a Combo project.
Usage
$ mix combo_new <template> <path> [--app APP] [--module MODULE]
Arguments
<template>- the name of a built-in template, or the address of a Git repo, which is useful to use your own templates.- Supported built-in templates:
vanilla,vite,inertia-react. - Supported protocols of the address of Git repos:
https://,ssh://,file://.
- Supported built-in templates:
<path>- the path of the generated project. It can be an absolute or a relative path. The OTP application name and base module name will be retrieved from the path, unless--appor--moduleoption is given.
Options
--app- the name of the OTP application. If it's not specified, the name will be retrieved from the<path>.--module- the name of the base module. If it's not specified, the name will be retrieved from the name of the OTP application.-v,--version- prints the version.
Examples
Generates a project from the vanilla template in the ./demo
directory:
$ mix combo_new vanilla demo
Generates a project in the ./demo directory, using a remote Git repository
as the template:
$ mix combo_new https://github.com/namespace/name.git demo
Generates a project from the vanilla template in the /tmp/demo
directory:
$ mix combo_new vanilla /tmp/demo
Generates a project from the vanilla template in the ./demo
directory, but specifying the name of the OTP application as rina:
$ mix combo_new vanilla demo --app rina