View Source mix combo_new.update (combo_new v0.12.0)
Updates combo_new locally.
Usage
$ mix combo_new.update
It accepts the same command line options as archive.install hex combo_new.
Updates combo_new locally.
$ mix combo_new.update
It accepts the same command line options as archive.install hex combo_new.